﻿using Syncfusion.Pdf;
using Syncfusion.Pdf.Parsing;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading;
using System.Threading.Tasks;

namespace CompressionSample
{
    class Program
    {
        static void Main(string[] args)
        {
            if (RunWithTimeout(LongRunningOperation, TimeSpan.FromMilliseconds(1000)))
            {
                Console.WriteLine("Worker thread finished.");
            }
            else
            {
                Console.WriteLine("Worker thread was aborted.");
            }

            Console.ReadLine();
        }

        static bool RunWithTimeout(ThreadStart threadStart, TimeSpan timeout)
        {
            Thread workerThread = new Thread(threadStart);

            workerThread.Start();

            bool finished = workerThread.Join(timeout);
            if (!finished)
                workerThread.Abort();

            return finished;
        }

        static void LongRunningOperation()
        {
            //Load the existing PDF document
            PdfLoadedDocument loadedDocument = new PdfLoadedDocument("../../Data/Brochure.pdf");

            //Create a new compression option.
            PdfCompressionOptions options = new PdfCompressionOptions();

            //Enable the compress image.
            options.CompressImages = true;

            //Set the image quality.
            options.ImageQuality = 50;

            //Enable the optimize font option
            options.OptimizeFont = true;

            //Enable the optimize page contents.
            options.OptimizePageContents = true;

            //Assign the compression option to the document
            loadedDocument.CompressionOptions = options;

            //Save the PDF document
            loadedDocument.Save("Output.pdf");

            //Close the document
            loadedDocument.Close(true);
        }
    }
}
